==> traccar_gennissi-0.0.8.tar.gz: lib/src/model/User.dart <==
class User extends Object {
  int id;
  Map<String, dynamic> attributes;
  String name;
  String login;
  String email;
  String phone;
  bool readonly;
  bool administrator;
  String map;
  double latitude;
  double longitude;
  int zoom;
  bool twelveHourFormat;
  String coordinateFormat;
  bool disabled;
  String expirationTime;
  int deviceLimit;
  int userLimit;
  bool deviceReadonly;
  String token;
  bool limitCommands;
  String poiLayer;
  String password;

  User(
      {this.id,
      this.attributes,
      this.name,
      this.login,
      this.email,
      this.phone,
      this.readonly,
      this.administrator,
      this.map,
      this.latitude,
      this.longitude,
      this.zoom,
      this.twelveHourFormat,
      this.coordinateFormat,
      this.disabled,
      this.expirationTime,
      this.deviceLimit,
      this.userLimit,
      this.deviceReadonly,
      this.token,
      this.limitCommands,
      this.poiLayer,
      this.password});

  User.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    attributes = json["attributes"];
    name = json["name"];
    login = json["login"];
    email = json["email"];
    phone = json["phone"];
    readonly = json["readonly"];
    administrator = json["administrator"];
    map = json["map"];
    latitude = json["latitude"];
    longitude = json["longitude"];
    zoom = json["zoom"];
    twelveHourFormat = json["twelveHourFormat"];
    coordinateFormat = json["coordinateFormat"];
    disabled = json["disabled"];
    expirationTime = json["expirationTime"];
    deviceLimit = json["deviceLimit"];
    userLimit = json["userLimit"];
    deviceReadonly = json["deviceReadonly"];
    token = json["token"];
    limitCommands = json["limitCommands"];
    poiLayer = json["poiLayer"];
    password = json["password"];
  }

  Map<String, dynamic> toJson() => {
        'id': id,
        'attributes': attributes,
        'name': name,
        'login': login,
        'email': email,
        'phone': phone,
        'readonly': readonly,
        'administrator': administrator,
        'map': map,
        'latitude': latitude,
        'longitude': longitude,
        'zoom': zoom,
        'twelveHourFormat': twelveHourFormat,
        'coordinateFormat': coordinateFormat,
        'disabled': disabled,
        'expirationTime': expirationTime,
        'deviceLimit': deviceLimit,
        'userLimit': userLimit,
        'deviceReadonly': deviceReadonly,
        'token': token,
        'limitCommands': limitCommands,
        'poiLayer': poiLayer,
        'password': password
      };
}

==> traccar_gennissi-0.0.21.tar.gz: lib/src/model/User.dart <==
class User extends Object {
  int? id;
  Map<String, dynamic>? attributes;
  String? name;
  String? email;
  String? phone;
  bool? readonly;
  bool? administrator;
  String? map;
  double? latitude;
  double? longitude;
  int? zoom;
  bool? twelveHourFormat;
  String? coordinateFormat;
  bool? disabled;
  String? expirationTime;
  int? deviceLimit;
  int? userLimit;
  bool? deviceReadonly;
  String? token;
  bool? limitCommands;
  String? poiLayer;
  String? password;

  User(
      {id,
      attributes,
      name,
      login,
      email,
      phone,
      readonly,
      administrator,
      map,
      latitude,
      longitude,
      zoom,
      twelveHourFormat,
      coordinateFormat,
      disabled,
      expirationTime,
      deviceLimit,
      userLimit,
      deviceReadonly,
      token,
      limitCommands,
      poiLayer,
      password});

  User.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    attributes = json["attributes"];
    name = json["name"];
    email = json["email"];
    phone = json["phone"];
    readonly = json["readonly"];
    administrator = json["administrator"];
    map = json["map"];
    latitude = json["latitude"];
    longitude = json["longitude"];
    zoom = json["zoom"];
    twelveHourFormat = json["twelveHourFormat"];
    coordinateFormat = json["coordinateFormat"];
    disabled = json["disabled"];
    expirationTime = json["expirationTime"];
    deviceLimit = json["deviceLimit"];
    userLimit = json["userLimit"];
    deviceReadonly = json["deviceReadonly"];
    token = json["token"];
    limitCommands = json["limitCommands"];
    poiLayer = json["poiLayer"];
    password = json["password"];
  }

  Map<String, dynamic> toJson() => {
        'id': id,
        'attributes': attributes,
        'name': name,
        'email': email,
        'phone': phone,
        'readonly': readonly,
        'administrator': administrator,
        'map': map,
        'latitude': latitude,
        'longitude': longitude,
        'zoom': zoom,
        'twelveHourFormat': twelveHourFormat,
        'coordinateFormat': coordinateFormat,
        'disabled': disabled,
        'expirationTime': expirationTime,
        'deviceLimit': deviceLimit,
        'userLimit': userLimit,
        'deviceReadonly': deviceReadonly,
        'token': token,
        'limitCommands': limitCommands,
        'poiLayer': poiLayer,
        'password': password
      };
}
